@@ -1,7 +1,7 @@
 # This file provides some standard formatters
 # This prints out a string in the following format:
 #   LEVEL [timestamp] message
-simpleLayout <- function(level, msg, ...)
+layout.simple <- function(level, msg, ...)
 {
   the.time <- format(Sys.time(), "%Y-%m-%d %H:%M:%S")
   if (! is.null(substitute(...))) msg <- sprintf(msg, ...)
@@ -14,8 +14,10 @@ simpleLayout <- function(level, msg, ...)
 # %m - Message
 # %f - Calling function
 # TODO: INCOMPLETE
-formatLayout <- function(level, msg, format, ...)
+layout.format <- function(format)
 {
-  if (! is.null(substitute(...))) msg <- sprintf(msg, ...)
+  function(level, msg, ...) {
+    if (! is.null(substitute(...))) msg <- sprintf(msg, ...)
+  }
 }
 
